@@ -235,7 +235,7 @@ deserializePackages <- function(df) {
   df <- df[, names(df) != 'requires', drop = FALSE]
 
   sortedPackages <- lapply(topoSorted, function(pkgName) {
-    pkg <- as.list(df[df$name == pkgName,])
+    pkg <- as.list(df[df$name == pkgName, ])
     pkg <- pkg[!is.na(pkg)]
     return(pkg)
   })
@@ -282,7 +282,9 @@ aliases <- c(
   RemoteHost = "remote_host",
   RemoteRepo = "remote_repo",
   RemoteUsername = "remote_username",
+  RemoteRef = "remote_ref",
   RemoteSha = "remote_sha",
+  RemoteSubdir = "remote_subdir",
   SourcePath = "source_path",
   Hash = "hash"
 )
